==> net.java.html.lib-0.2-sources.jar: net/java/html/lib/PropertyDescriptor.java <==
package net.java.html.lib;
public class PropertyDescriptor extends net.java.html.lib.Objs {
  protected PropertyDescriptor(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<PropertyDescriptor> {
    $Constructor() {
      super(PropertyDescriptor.class);
    }
    @Override
    public PropertyDescriptor create(java.lang.Object obj) {
      return obj == null ? null : new PropertyDescriptor(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static PropertyDescriptor $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  public net.java.html.lib.Objs.Property<java.lang.Boolean> configurable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "configurable");
  public java.lang.Boolean configurable() { return configurable.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Boolean> enumerable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "enumerable");
  public java.lang.Boolean enumerable() { return enumerable.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Object> value = net.java.html.lib.Objs.Property.create(this, java.lang.Object.class, "value");
  public net.java.html.lib.Objs.Property<java.lang.Boolean> writable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "writable");
  public java.lang.Boolean writable() { return writable.get(); }
  public java.lang.Object get() {
    return $Typings$.get$409($js(this));
  }
  public void set(java.lang.Object v) {
    $Typings$.set$410($js(this), /* AnyKeyword*/$js(v));
  }
}

==> net.java.html.lib-0.6-sources.jar: net/java/html/lib/PropertyDescriptor.java <==
package net.java.html.lib;
public class PropertyDescriptor extends net.java.html.lib.Objs {
  protected PropertyDescriptor(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<PropertyDescriptor> {
    $Constructor() {
      super(PropertyDescriptor.class);
    }
    @Override
    public PropertyDescriptor create(java.lang.Object obj) {
      return obj == null ? null : new PropertyDescriptor(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static PropertyDescriptor $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  public net.java.html.lib.Objs.Property<java.lang.Boolean> configurable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "configurable");
  public java.lang.Boolean configurable() { return configurable.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Boolean> enumerable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "enumerable");
  public java.lang.Boolean enumerable() { return enumerable.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Object> value = net.java.html.lib.Objs.Property.create(this, java.lang.Object.class, "value");
  public net.java.html.lib.Objs.Property<java.lang.Boolean> writable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "writable");
  public java.lang.Boolean writable() { return writable.get(); }
  public java.lang.Object get() {
    return net.java.html.lib.Objs.$as(java.lang.Object.class, $Typings$.get$409($js(this)));
  }
  public void set(java.lang.Object v) {
    $Typings$.set$410($js(this), /* AnyKeyword*/$js(v));
  }
}
